#!/usr/bin/env python
# encoding: utf-8

from pyramid.config import Configurator
from pyramid.i18n import TranslationStringFactory

from ringo.lib.sql.db import setup_db_session, setup_db_engine
from ringo.lib.sitetree import site_tree_branches
from ringo.model import Base
from ringo.lib.i18n import translators
from waskiq.model import extensions

sitetree = {
    "baustein_cms": {"parent_site": "participations",
                     "parent_item": "participation",
                     "display_item": "participation",
                     "display_format": "Baustein CM"},
    "baustein_mps": {"parent_site": "participations",
                     "parent_item": "participation",
                     "display_item": "participation",
                     "display_format": "Baustein MP"},
    "baustein_jsas": {"parent_site": "participations",
                      "parent_item": "participation",
                      "display_item": "participation",
                      "display_format": "Baustein AJSA"},
    "baustein_clearings": {"parent_site": "participations",
                           "parent_item": "participation",
                           "display_item": "participation",
                           "display_format": "Baustein CL"},
    "angebots": {"parent_site": "baustein_cms",
                 "parent_item": "baustein_cm",
                 "display_item": "baustein_cm",
                 "display_format": u"Maßnahme"}
}

site_tree_branches.append(sitetree)


def main(global_config, **settings):
    """ This function returns a Pyramid WSGI application.
    """
    engine = setup_db_engine(settings)
    setup_db_session(engine)
    Base.metadata.bind = engine
    config = Configurator(settings=settings)
    # Include basic ringo configuration.
    config.include('ringo')
    config.include('efa')
    config.include('waskiq')
    for extension in extensions:
        config.include(extension)
    config.scan('efa')
    config.commit()
    config.scan()
    config.commit()
    return config.make_wsgi_app()


def includeme(config):
    # Now configure the application and optionally overwrite previously
    translators.append(TranslationStringFactory('waskiq'))
    config.add_translation_dirs('waskiq:locale/')
    config.add_static_view('waskiq-static', path='waskiq:static',
                           cache_max_age=3600)
