"""Split primary key of baustein into separate PK and FK

Revision ID: 108a693898f0
Revises: 3beeee755c49
Create Date: 2015-11-26 13:07:14.178454

"""

# revision identifiers, used by Alembic.
revision = '108a693898f0'
down_revision = '3beeee755c49'

from alembic import op
import sqlalchemy as sa


INSERTS = """
UPDATE baustein_clearings set participation_id = id;
CREATE SEQUENCE baustein_clearings_id_seq START 1;
select setval('baustein_clearings_id_seq',  (select coalesce(max(id), 1)+1 from baustein_clearings));
alter table baustein_clearings ALTER COLUMN id SET DEFAULT nextval('baustein_clearings_id_seq');
UPDATE baustein_jsas set participation_id = id;
CREATE SEQUENCE baustein_jsas_id_seq START 1;
select setval('baustein_jsas_id_seq',  (select coalesce(max(id), 1)+1 from baustein_jsas));
alter table baustein_jsas ALTER COLUMN id SET DEFAULT nextval('baustein_jsas_id_seq');
UPDATE baustein_mps set participation_id = id;
CREATE SEQUENCE baustein_mps_id_seq START 1;
select setval('baustein_mps_id_seq',  (select coalesce(max(id), 1)+1 from baustein_mps));
alter table baustein_mps ALTER COLUMN id SET DEFAULT nextval('baustein_mps_id_seq');
UPDATE baustein_cms set participation_id = id;
CREATE SEQUENCE baustein_cms_id_seq START 1;
select setval('baustein_cms_id_seq',  (select coalesce(max(id), 1)+1 from baustein_cms));
alter table baustein_cms ALTER COLUMN id SET DEFAULT nextval('baustein_cms_id_seq');
"""
DELETES = """"""


def iter_statements(stmts):
    for st in [x for x in stmts.split('\n') if x]:
        op.execute(st)


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('baustein_clearings', sa.Column('participation_id', sa.Integer(), nullable=True))
    op.drop_constraint(u'baustein_clearings_id_fkey', 'baustein_clearings', type_='foreignkey')
    op.create_foreign_key(None, 'baustein_clearings', 'participations', ['participation_id'], ['id'])
    op.add_column('baustein_jsas', sa.Column('participation_id', sa.Integer(), nullable=True))
    op.drop_constraint(u'baustein_jsas_id_fkey', 'baustein_jsas', type_='foreignkey')
    op.create_foreign_key(None, 'baustein_jsas', 'participations', ['participation_id'], ['id'])
    op.add_column('baustein_mps', sa.Column('participation_id', sa.Integer(), nullable=True))
    op.drop_constraint(u'baustein_mps_id_fkey', 'baustein_mps', type_='foreignkey')
    op.create_foreign_key(None, 'baustein_mps', 'participations', ['participation_id'], ['id'])
    op.add_column('baustein_cms', sa.Column('participation_id', sa.Integer(), nullable=True))
    op.drop_constraint(u'baustein_cms_id_fkey', 'baustein_cms', type_='foreignkey')
    op.create_foreign_key(None, 'baustein_cms', 'participations', ['participation_id'], ['id'])
    ### end Alembic commands ###
    iter_statements(INSERTS)


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'baustein_mps', type_='foreignkey')
    op.create_foreign_key(u'baustein_mps_id_fkey', 'baustein_mps', 'participations', ['id'], ['id'])
    op.drop_column('baustein_mps', 'participation_id')
    op.drop_constraint(None, 'baustein_jsas', type_='foreignkey')
    op.create_foreign_key(u'baustein_jsas_id_fkey', 'baustein_jsas', 'participations', ['id'], ['id'])
    op.drop_column('baustein_jsas', 'participation_id')
    op.drop_constraint(None, 'baustein_clearings', type_='foreignkey')
    op.create_foreign_key(u'baustein_clearings_id_fkey', 'baustein_clearings', 'participations', ['id'], ['id'])
    op.drop_column('baustein_clearings', 'participation_id')
    op.drop_constraint(None, 'baustein_cms', type_='foreignkey')
    op.create_foreign_key(u'baustein_cms_id_fkey', 'baustein_cms', 'participations', ['id'], ['id'])
    op.drop_column('baustein_cms', 'participation_id')
    ### end Alembic commands ###
    iter_statements(DELETES)
