import sqlalchemy as sa
from sqlalchemy.ext.declarative import declared_attr
from ringo.model import Base
from ringo.model.base import BaseItem
from ringo.model.mixins import Owned
from ringo.lib.helpers import get_item_modul


class Baustein(BaseItem, Owned, Base):

    """Base-class for all Baustein classes except the CM Baustein."""

    __abstract__ = True

    @declared_attr
    def id(cls):
        return sa.Column(sa.Integer,
                         primary_key=True)

    @declared_attr
    def participation_id(cls):
        return sa.Column(sa.Integer, sa.ForeignKey("participations.id"))

    @declared_attr
    def participation(cls):
        refname = cls.__tablename__
        return sa.orm.relation("WaskiqParticipation",
                               backref=sa.orm.backref(refname,
                                                      cascade="delete, all"))

    # TODO: Is this method really needed? Usually the Baustein will be
    # created by the same user that creates the related participation.
    # So the custom logic will have no effect in most cases. The only
    # situation where this can happen is if the participation is created
    # but no baustein has been selected (created) so far. Now another
    # user finshes this process. If the origin creator is not standin of
    # the use who created the baustein, he will not be able to access
    # the baustein.
    # (ti) <2015-03-20 10:50>
    @classmethod
    def _get_permissions(cls, modul, item, request):
        """Specfic implementation of building the permissons for this class.
        Access to this item shall be granted to all user who have
        _direct_ access to the Baustein (default) and _indirectly_ because
        they have access to the participation."""
        # Default ACL. Direct access
        permissions = BaseItem._get_permissions(modul, item, request)
        if item is None:
            return permissions

        # Custom ACL. Indirect access through the participation
        participation = item.participation
        if not participation:
            return permissions
        modul = get_item_modul(request, participation)
        permissions.extend(item.participation._get_permissions(modul,
                                                               participation,
                                                               request))
        return permissions
