import sqlalchemy as sa

from ringo.model import Base
from ringo.model.base import BaseItem
from ringo.model.mixins import Owned
from ringo.lib.helpers import get_item_modul
from ringo_printtemplate.model import Printable


class BausteinCM(BaseItem, Owned, Printable, Base):
    __tablename__ = 'baustein_cms'
    _modul_id = 2001
    id = sa.Column(sa.Integer, primary_key=True)
    participation_id = sa.Column(sa.Integer,
                                 sa.ForeignKey("participations.id"))
    integrationschule = sa.Column('integrationschule', sa.Integer)
    berufsberatung = sa.Column('berufsberatung', sa.Integer)
    berufsvorbereitung = sa.Column('berufsvorbereitung', sa.Integer)
    lebensbewaeltigung = sa.Column('lebensbewaeltigung', sa.Integer)
    integrationsprache = sa.Column('integrationsprache', sa.Integer)
    sonstigerbedarf = sa.Column('sonstigerbedarf', sa.Integer)
    sonstiges = sa.Column('sonstiges', sa.String, nullable=False, default='')
    datum = sa.Column('datum', sa.Date)
    doku = sa.Column('doku', sa.String, nullable=False, default='')

    angebot = sa.orm.relation("Angebot", cascade="delete, all")
    participation = sa.orm.relation("WaskiqParticipation",
                                    backref=sa.orm.backref(
                                        __tablename__,
                                        cascade="delete, all"))

    # TODO: Is this method really needed? Usually the Baustein will be
    # created by the same user that creates the related participation.
    # So the custom logic will have no effect in most cases. The only
    # situation where this can happen is if the participation is created
    # but no baustein has been selected (created) so far. Now another
    # user finshes this process. If the origin creator is not standin of
    # the use who created the baustein, he will not be able to access
    # the baustein.
    # (ti) <2015-03-20 10:50>
    @classmethod
    def _get_permissions(cls, modul, item, request):
        """Specfic implementation of building the permissons for this class.
        Access to this item shall be granted to all user who have
        _direct_ access to the Baustein (default) and _indirectly_ because
        they have access to the participation."""
        # Default ACL. Direct access
        permissions = BaseItem._get_permissions(modul, item, request)
        if item is None:
            return permissions

        # Custom ACL. Indirect access through the participation
        participation = item.participation
        if not participation:
            return permissions
        modul = get_item_modul(request, participation)
        permissions.extend(item.participation._get_permissions(modul,
                                                               participation,
                                                               request))
        return permissions
