import sqlalchemy as sa
from efa.model.outputindicator import Outputindicator
from ringo.lib.form import get_form_config
from formbar.form import Form


class WaskiqOutputindicator(Outputindicator):
    """Waskiq specific Outputindicators. Adds some local fields.
    """

    waskiqparticipation = sa.orm.relation(
        "Participation",
        enable_typechecks=False,
        backref=sa.orm.backref("waskiqoi",
                               uselist=False,
                               cascade="all"))

    # Status of the outputindicators
    status = sa.Column('status', sa.Integer)

    # Education situation
    edu_attainment_school = sa.Column(
        'edu_attainment_school', sa.Integer)
    edu_attainment_vocational = sa.Column(
        'edu_attainment_vocational', sa.Integer)

    # Labour market situation
    lm_employment_category_employed = sa.Column(
        'lm_employment_category_employed', sa.Integer)
    lm_employment_category_underemployed = sa.Column(
        'lm_employment_category_underemployed', sa.Integer)
    lm_employment_category_selfemployed = sa.Column(
        'lm_employment_category_selfemployed', sa.Integer)
    lm_employment_category_education_enterprise = sa.Column(
        'lm_employment_category_education_enterprise', sa.Integer)
    lm_employment_category_inactive = sa.Column(
        'lm_employment_category_inactive', sa.Integer)
    lm_employment_category_education_school = sa.Column(
        'lm_employment_category_education_school', sa.Integer)
    lm_employment_category_school = sa.Column(
        'lm_employment_category_school', sa.Integer)
    lm_employment_category_fulltime_student = sa.Column(
        'lm_employment_category_fulltime_student', sa.Integer)
    lm_employment_category_training = sa.Column(
        'lm_employment_category_training', sa.Integer)
    lm_employment_category_unemployed = sa.Column(
        'lm_employment_category_unemployed', sa.Integer)
    lm_employment_category_unemployement_type = sa.Column(
        'lm_employment_category_unemployement_type', sa.Integer)
    lm_employment_category_lookingforwork = sa.Column(
        'lm_employment_category_lookingforwork', sa.Integer)
    lm_employment_supportpurchased = sa.Column(
        'lm_employment_supportpurchased', sa.Integer)

    # Household situation
    hh_community = sa.Column('hh_community', sa.Integer)

    # Disabilities
    da_refugee = sa.Column('da_refugee', sa.Integer)
    da_refugee_months = sa.Column('da_refugee_months', sa.Integer)
    da_resident = sa.Column('da_resident', sa.Integer)

    # General
    misc_further_participation = sa.Column(
        'misc_further_participation', sa.Integer)
    misc_birthcountry_germany = sa.Column(
        'misc_birthcountry_germany', sa.Integer)
    misc_birthcountry_parent_germany = sa.Column(
        'misc_birthcountry_parent_germany', sa.Integer)
    misc_german_nationality = sa.Column(
        'misc_german_nationality', sa.Integer)
    misc_other_nationality = sa.Column(
        'misc_other_nationality', sa.String, nullable=False, default='')

    def is_complete(self):
        if self.status is not None:
            if self.status == 1:
                return True
            else:
                return False
        form_config = get_form_config(self, "update")
        form = Form(form_config, self)
        form.validate()

        status = not form.has_errors() and not form.has_warnings()
        if status:
            self.status = 1
        else:
            self.status = 0
        return status
