# -*- coding: utf8 -*-

import sqlalchemy as sa
from euhu.esf import to_esf
from euhu.programs.waskiq import to_bmas, validate
from efa.model.participant import (
    Participant,
    generate_determine_reportable_function,
    listener_adapter
)
from ringo_bmasreport.reports.durchfuehrungsbericht import (
    indicators, recipe
)


program = "waskiq"
indicators['OI'].append(('PO04', u'Benachteiligte Jugendliche U27 (PO04)'))
indicators['RI'].append((
    'B3.2',
    u'Benachteiligte U27-Jährige mit erhöhtem sozialpädagogischem '
    u'Unterstützungsbedarf am Übergang Schule-Beruf, die nach ihrer '
    u'Teilnahme einen Arbeitsplatz haben oder eine schulische/berufliche '
    u'Bildung absolvieren (B3.2)'))


def derive_indicators(values):
    return to_esf(to_bmas(values)).esf


class WaskiqParticipant(Participant):
    """Special Waskiq version of participant saves"""
    # TODO: Clarify if this field is of value in other installations to
    # and then move it into efa. (ti) <2016-02-04 13:31>
    participant_eligible = sa.Column('participant_eligible',
                                     sa.Integer)

td_update_listener = listener_adapter(generate_determine_reportable_function(
    derive_indicators,
    recipe,
    validate,
    program))

sa.event.listen(WaskiqParticipant, 'after_update', td_update_listener)
