from efa.model.resultindicators import ResultIndicators
import sqlalchemy as sa


class WaskiqResultIndicators(ResultIndicators):
    """
    Result indicators for WASIQ

    These are the result indicators from eFa with some few additional fields
    """

    problems_solved = sa.Column('problems_solved', sa.Integer)
    problem_situation = sa.Column('problem_situation', sa.Integer)
    regular_school_visits = sa.Column('regular_school_visits', sa.Integer)
    work_school_situation = sa.Column('work_school_situation', sa.Integer)

    # Setting cascade to custom value to avoid ISE when triggering
    # See stackoverflow.com/questions/23699651/
    waskiqparticipation = sa.orm.relation(
        "Participation",
        enable_typechecks=False,
        backref=sa.orm.backref("waskiqri",
                               uselist=False,
                               cascade=("save-update, merge, "
                                        "delete, delete-orphan")))
    """Relation to the Participation. If the participation is deleted
    the depending outputindicatotrs are deleted too. Also disable
    typechecks here to allow subclasses of Participation to be linked
    with the Outputindicator."""
