# encoding: utf-8
import logging
from pyramid.httpexceptions import HTTPFound
from pyramid.view import view_config
from ringo.lib.helpers import get_action_routename, get_item_modul
from waskiq.model.baustein_mp import BausteinMP
from waskiq.views.baustein_cms import (
    delete_ as delete,
    _render_info_max_baustein,
    _is_max_baustein,
    get_related_item_from_request
)


log = logging.getLogger(__name__)


@view_config(route_name=get_action_routename(BausteinMP, 'create'),
             renderer="/default/create.mako",
             permission='create'
             )
def create_(request):
    if _is_max_baustein(request):
        return _render_info_max_baustein(request)
    clazz = request.context.__model__
    item_label = get_item_modul(request, clazz).get_label()
    participation = get_related_item_from_request(request)
    factory = BausteinMP.get_item_factory()
    baustein = factory.create(request.user, {})
    baustein.participation = participation
    baustein.save({}, request)
    msg = u"Baustein erfolgreich angelegt."
    request.session.flash(msg, 'success')
    log_msg = u'User {user.login} created {item_label} {item.id}'\
        .format(item_label=item_label, item=baustein, user=request.user)
    log.info(log_msg)
    return HTTPFound(request.GET.get('backurl'))


@view_config(route_name=get_action_routename(BausteinMP, 'delete'),
             renderer="/default/confirm.mako",
             permission='delete'
             )
def delete_(request):
    return delete(request)
