# -*- coding: utf-8 -*-
from pyramid.view import view_config
from pyramid.renderers import render_to_response
from efa.views.export_participants import build_response, FilterConfig
from efa.views.export_participations import access_allowed
from efa.views.export_participations import prepare_form, get_metadata
from efa.model.project import Project
from efa.model.organisation import Organisation


class WaskiqFilterConfig(FilterConfig):

    def __init__(self, entry_filter, gender_filter, start, end, projects,
                 organisations):
        self.entry_filter = entry_filter
        self.gender_filter = gender_filter
        self.start = start
        self.end = end
        self.projects = projects
        self.organisations = organisations
        self.foerderphase = 'both'

    def filter(self, virtual_participations):
        filtered_vpns = super(WaskiqFilterConfig, self).filter(
            virtual_participations)
        if self.projects:
            filtered_vpns = [vpn for vpn in filtered_vpns
                             if vpn.get("project_name") in self.projects]
        if self.organisations:
            filtered_vpns = [vpn for vpn in filtered_vpns
                             if vpn.get("organisation_name")
                             in self.organisations]
        return filtered_vpns


def get_project_id_map(db):
    projects = db.query(Project).all()
    project_dict = {project.id: project.name for project in projects}

    def helper(list_):
        if not list_:
            return None
        return [project_dict.get(id_) for id_ in list_]
    return helper


def get_organisation_id_map(db):
    organisations = db.query(Organisation).all()
    organisation_dict = {orga.id: orga.name for orga in organisations}

    def helper(list_):
        if not list_:
            return None
        return [organisation_dict.get(id_) for id_ in list_]
    return helper


def get_filters_from(form, db):
    filter_type_map = {1: "entry_and_exit_in", 2: "entry_in", 3: "exit_in",
                       4: "entry_or_exit_in", 5: "running_while",
                       -1: "no_filter"}
    gender_map = {0: "only_female", 1: "only_male", None: "both"}
    return WaskiqFilterConfig(filter_type_map[form.data.get("filter_type")],
                              gender_map.get(form.data.get("gender", "both")),
                              form.data.get('start_date'),
                              form.data.get('end_date'),
                              get_project_id_map(db)(
                                  form.data.get('projects')),
                              get_organisation_id_map(db)(
                                  form.data.get('organisations')))


@view_config(route_name='participants-excelexport',
             renderer='/excelexportform.mako',
             request_method='GET')
def participations_excelexport_form_waskiq(request):
    access_allowed(request.user)
    form = prepare_form(request, "participations")
    return {'form': form, 'rendered_form': form.render(),
            'exportname': 'Teilnehmende'}


@view_config(route_name='participants-excelexport',
             request_method='POST')
def participants_excel_export_waskiq(request):
    access_allowed(request.user)

    form = prepare_form(request, "participants")
    form.validate(request.POST)

    if not form.has_errors():
        filters = get_filters_from(form, request.db)
        metadata = get_metadata(request, form)
        return build_response(request, filters, "waskiq", metadata)
    else:
        return render_to_response('/excelexportform.mako',
                                  {'form': form,
                                   'rendered_form': form.render(),
                                   'exportname': 'Teilnehmende'},
                                  request)
