from pyramid.view import view_config
from ringo.model.base import get_item_list
from efa.views.home import index_view as efa_index_view
from waskiq.model.participant import WaskiqParticipant
import itertools


def get_participant_eligible_items(request):
    """Should return the participants, which habe no eligible information
    and should be looked at."""
    participants = request.db.query(WaskiqParticipant)\
        .filter(WaskiqParticipant.participant_eligible == None).all()
    items = get_item_list(request, WaskiqParticipant, user=request.user,
                          items=participants).items
    return items


@view_config(route_name='home', renderer='/index.mako')
def index_view(request):
    values = efa_index_view(request)
    values['participant_eligible_items'] = get_participant_eligible_items(
        request)
    values['oi_missing'] = check_for_missing_outputindicators(request)

    return values


def check_for_missing_outputindicators(request):
    participants = request.db.query(WaskiqParticipant).all()
    filtered_participants = get_item_list(request,
                                          WaskiqParticipant,
                                          user=request.user,
                                          items=participants).items
    participants_without_oi = (p for p in filtered_participants if no_oi(p))
    participations = (p.participations for p in participants_without_oi)
    return [i for i in itertools.chain(*participations)]


def no_oi(participant):
    has_oi = lambda p: not p.oi is None
    return not any((has_oi(p) for p in participant.participations))
