import logging
from pyramid.httpexceptions import HTTPFound
from pyramid.view import view_config
from ringo.model.user import User
from ringo.lib.helpers import (
    get_action_routename
)
from ringo.views.helpers import get_item_from_request
from ringo.views.request import get_return_value

from efa.lib.renderer import ParticipationTransferRenderer
from efa.views.participant import transfer_participations

from waskiq.model.participation import WaskiqParticipation

log = logging.getLogger(__name__)

_ = lambda x: x


# Transfers participations including journals, outputindicators
# and modules from one user to another one
def transfer_modules(request, user, coworker_id):
    participations = request.db.query(WaskiqParticipation)\
        .filter(user.id == WaskiqParticipation.uid)
    coworker = request.db.query(User)\
        .filter(coworker_id == User.id).one()
    for p in participations:
        coworker_gid = coworker.default_gid
        if len(p.baustein_mps) != 0:
            p.baustein_mps[0].uid = coworker_id
            if p.baustein_mps[0].gid is not None:
                p.baustein_mps[0].gid = coworker_gid
        if len(p.baustein_cms) != 0:
            p.baustein_cms[0].uid = coworker_id
            if p.baustein_cms[0].gid is not None:
                p.baustein_cms[0].gid = coworker_gid
        if len(p.baustein_clearings) != 0:
            p.baustein_clearings[0].uid = coworker_id
            if p.baustein_clearings[0].gid is not None:
                p.baustein_clearings[0].gid = coworker_gid
        if len(p.baustein_jsas) != 0:
            p.baustein_jsas[0].uid = coworker_id
            if p.baustein_jsas[0].gid is not None:
                p.baustein_jsas[0].gid = coworker_gid
    transfer_participations(request, user, coworker_id)


@view_config(route_name=get_action_routename(User, 'waskiq-transfer'),
             renderer='/default/confirm.mako',
             permission='update')
def _transfer(request):
    item = get_item_from_request(request)
    url = request.route_path(get_action_routename(User,
                                                  'update'),
                             id=item.id)

    if request.POST:
        coworker_id = request.params.get('coworker')
        transfer_modules(request, item, coworker_id)
        url = request.route_path(get_action_routename(User,
                                                      'update'),
                                 id=item.id)
        return HTTPFound(url)

    participations = request.db.query(WaskiqParticipation)\
        .filter(item.id == WaskiqParticipation.uid)
    participations = participations.count()

    if participations > 0:
        organisation = item.organisation
        len_users = len(organisation[0].users)
        if len_users > 1:
            renderer = ParticipationTransferRenderer(request, item)
            rvalues = get_return_value(request)
            rvalues['dialog'] = renderer.render([item])
            return rvalues
        else:
            _ = request.translate
            msg = _("Organisation of User '%s' does not have further "
                    "employees.") % unicode(item)
            request.session.flash(msg, 'error')

    else:
        _ = request.translate
        msg = _("User '%s' does not have any participations "
                "to transfer.") % unicode(item)
        request.session.flash(msg, 'error')
    return HTTPFound(url)
